<?php

/**
 * Text Ticker package for Concrete5
 * Copyright 2020, Alex Borisov. All Rights Reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2018-2020, Alex Borisov. All Rights Reserved.
 * @package Concrete\Package\ab_text_ticker
 */

namespace Concrete\Package\AbTextTicker\Block\AbTextTicker;

use Concrete\Core\Block\BlockController;

class Controller extends BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "400";
    protected $btTable = 'btAbTextTicker';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Text Ticker block");
    }

    public function getBlockTypeName() 
    {
        return t("Text Ticker");
    }

    public function registerViewAssets($outputContent = '')
    {
        $this->requireAsset('javascript', 'jquery');
    }
    
    public function save($data)
    {
        $data['ticker_text'] = isset($data['ticker_text']) ? trim(str_replace(["\n", "\r", "  "], " ", strip_tags(html_entity_decode($data['ticker_text'], ENT_QUOTES, 'UTF-8')))) : '';
        parent::save($data);
    }
    
    public function validate($data)
    {
        $e = $this->app->make('helper/validation/error');
        
        if ($data['ticker_text'] == '' || mb_strlen($data['ticker_text'], 'UTF-8') > 1000) {
            $e->add(t('Ticker Text cannot be empty and must have max 1000 characters'));
        }

        return $e;
    }
}
